==> gurux_dlms-1.0.12-py3-none-any.whl: gurux_dlms/objects/enums/CertificateType.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from enum import Enum

class CertificateType(Enum):
    """
    Certificate type.
    """
    #pylint: disable=too-few-public-methods

    #
    # Certificate type is digital signature.
    #
    DIGITAL_SIGNATURE = 0
    #
    # Certificate type is key agreement.
    #
    KEY_AGREEMENT = 1
    #
    # Certificate type is TLS.
    #
    TLS = 2
    #
    # Certificate type is other.
    #
    OTHER = 3

==> gurux_dlms-1.0.31-py3-none-any.whl: gurux_dlms/objects/enums/CertificateType.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
#pylint: disable=broad-except,no-name-in-module
try:
    from enum import IntEnum
    __base = IntEnum
except Exception:
    __base = object

class CertificateType(__base):
    """
    Certificate type.
    """
    #pylint: disable=too-few-public-methods

    #
    # Certificate type is digital signature.
    #
    DIGITAL_SIGNATURE = 0
    #
    # Certificate type is key agreement.
    #
    KEY_AGREEMENT = 1
    #
    # Certificate type is TLS.
    #
    TLS = 2
    #
    # Certificate type is other.
    #
    OTHER = 3
